@@ -256,6 +256,22 @@ namespace eval FormBroker {
         }
     }
 
+    proc validate_boolean {_var_d} {
+        upvar $_var_d var_d
+
+        dict with var_d {
+            if {[string is boolean $var]} {
+                if {$constrain} {
+                    set var [string is true $var]
+                }
+                return FB_OK
+            } else {
+                return FB_INVALID_BOOLEAN
+            }
+        }
+    }
+
+
     proc validate_variable_representation {_var_d} {
         upvar $_var_d var_d
         variable form_definitions
@@ -669,11 +685,14 @@ namespace eval FormBroker {
 
             # the 'vars' dictionary field stores the
             # order of form fields in which they are processed
-            # (in general this order is destroyed by the Tcl's hash
-            # tables algorithm)
+            # (in general this order would be destroyed by the Tcl's hash
+            # tables)
 
             dict with form_list $form_name {::lappend vars $field_name}
 
+            # this test would handle the case of the most simple possible
+            # variable definition (just the variable name)
+
             if {$field_type == ""} {
                 set field_type string
             }
@@ -698,6 +717,9 @@ namespace eval FormBroker {
                     email {
                         set validator [namespace current]::validate_email
                     }
+                    boolean {
+                        set validator [namespace current]::validate_boolean
+                    }
                     string -
                     default {
                         set validator [namespace current]::validate_string
